ReduxBridge | django_redux API Document

public class | source

# ReduxBridge

#### Extends:

WebSocketBridge → ReduxBridge

Bridge between Channels and Redux. By default dispatches actions received from channels to the redux store.

#### Example:

    const reduxBridge = new ReduxBridge();
    reduxBridge.connect();
    reduxBridge.listen(store);

## Inherited Summary

From class WebSocketBridge
public | connect(url: String, protocols: String[] | String, options: Object) Connect to the websocket server |
public | demultiplex(stream: String, cb: Function) Adds a 'stream handler' callback. |
public | listen(cb: Function) Starts listening for messages on the websocket, demultiplexing if necessary. |
public | send(msg: Object) Sends a message to the reply channel. |
public | stream(stream: String): Object Returns an object to send messages to a specific stream |